@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -105,7 +105,7 @@ our %DistToInstType = (
 
 our $OSDist;
 eval {
-    require Linux::Distribution;    ## nofilter(TidyAll::Plugin::OTRS::Perl::Require)
+    require Linux::Distribution;    ## nofilter(TidyAll::Plugin::Znuny::Perl::Require)
     import Linux::Distribution;
     $OSDist = Linux::Distribution::distribution_name() || '';
 };
@@ -124,12 +124,12 @@ GetOptions(
 
 # check needed params
 if ($Help) {
-    print "\nReturn all required and optional packages of OTRS.\n\n";
+    print "\nReturn all required and optional packages of Znuny.\n\n";
     print "Usage:\n";
-    print " otrs.CheckModules.pl [-list|all]\n\n";
+    print " znuny.CheckModules.pl [-list|all]\n\n";
     print "Options:\n";
     printf " %-22s - %s", '[-list]', 'Return an install command with all required packages.' . "\n";
-    printf " %-22s - %s", '[-all]',  'Return all required, optional and bundled packages of OTRS.' . "\n\n";
+    printf " %-22s - %s", '[-all]',  'Return all required, optional and bundled packages of Znuny.' . "\n\n";
     exit 1;
 }
 
@@ -187,6 +187,16 @@ my @NeededModules = (
             ports  => 'archivers/p5-Archive-Zip',
         },
     },
+    {
+        Module    => 'Authen::SASL',
+        Required  => 1,
+        Comment   => 'Required for SASL authentication mechanisms (e.g. IMAP and SMTP connections).',
+        InstTypes => {
+            aptget => 'libauthen-sasl-perl',
+            emerge => 'dev-perl/Authen-SASL',
+            zypper => 'perl-Authen-SASL',
+        },
+    },
     {
         Module    => 'Crypt::Eksblowfish::Bcrypt',
         Required  => 0,
@@ -198,6 +208,28 @@ my @NeededModules = (
             ports  => 'security/p5-Crypt-Eksblowfish',
         },
     },
+    {
+        Module    => 'Crypt::JWT',
+        Required  => 0,
+        Comment   => 'JSON web token support.',
+        InstTypes => {
+            aptget => 'libcrypt-jwt-perl',
+            emerge => 'dev-perl/Crypt-JWT',
+            zypper => 'perl-Crypt-JWT',
+            ports  => 'security/p5-Crypt-JWT',
+        },
+    },
+    {
+        Module    => 'Crypt::OpenSSL::X509',
+        Required  => 0,
+        Comment   => 'X509 certificate support.',
+        InstTypes => {
+            aptget => 'libcrypt-openssl-x509-perl',
+            emerge => 'dev-perl/Crypt-OpenSSL-X509',
+            zypper => 'perl-Crypt-OpenSSL-X509',
+            ports  => 'security/p5-Crypt-OpenSSL-X509',
+        },
+    },
     {
         Module    => 'CSS::Minifier::XS',
         Required  => 0,
@@ -209,6 +241,18 @@ my @NeededModules = (
             ports  => 'converters/p5-CSS-Minifier-XS',
         },
     },
+    {
+        Module    => 'Data::UUID',
+        Required  => 1,
+        Comment   => 'Required to generate UUIDs.',
+        InstTypes => {
+            aptget => undef,
+            emerge => undef,
+            yum    => undef,
+            zypper => undef,
+            ports  => undef,
+        },
+    },
     {
         Module    => 'Date::Format',
         Required  => 1,
@@ -326,6 +370,41 @@ my @NeededModules = (
             ports  => 'chinese/p5-Encode-HanExtra',
         },
     },
+    {
+        Module          => 'Excel::Writer::XLSX',
+        VersionRequired => '0.95',
+        Required        => 0,
+        Comment         => 'Required for the creation of Excel statistical reports.',
+        InstTypes       => {
+            aptget => 'libexcel-writer-xlsx-perl',
+            emerge => 'dev-perl/Excel-Writer-XLSX',
+            zypper => 'perl-Excel-Writer-XLSX',
+            ports  => 'textproc/p5-Excel-Writer-XLSX',
+        },
+    },
+    {
+        Module          => 'Hash::Merge',
+        VersionRequired => '0.300',
+        Required        => 0,
+        Comment         => 'Required for the creation of Excel statistical reports.',
+        InstTypes       => {
+            aptget => 'libhash-merge-perl',
+            emerge => 'dev-perl/Hash-Merge',
+            zypper => 'perl-Hash-Merge',
+            ports  => 'textproc/p5-Hash-Merge',
+        },
+    },
+    {
+        Module    => 'iCal::Parser',
+        Required  => 1,
+        Comment   => 'Required for calendar events.',
+        InstTypes => {
+            aptget => 'libical-parser-perl',
+            emerge => 'perl-core/iCal-Parser',
+            zypper => 'perl-iCal-Parser',
+            ports  => 'devel/p5-iCal-Parser',
+        },
+    },
     {
         Module              => 'IO::Socket::SSL',
         Required            => 0,
@@ -355,6 +434,18 @@ my @NeededModules = (
             ports  => 'converters/p5-JavaScript-Minifier-XS',
         },
     },
+    {
+        Module   => 'Jq',
+        Required => 0,
+        Comment =>
+            'Support for extended condition checking via Jq for the generic interface.',
+        InstTypes => {
+            aptget => undef,
+            emerge => undef,
+            zypper => undef,
+            ports  => undef,
+        },
+    },
     {
         Module    => 'JSON::XS',
         Required  => 0,
@@ -391,8 +482,7 @@ my @NeededModules = (
     {
         Module          => 'Mail::IMAPClient',
         VersionRequired => '3.22',
-        Comment         => 'Required for IMAP TLS connections.',
-        Required        => 0,
+        Required        => 1,
         InstTypes       => {
             aptget => 'libmail-imapclient-perl',
             emerge => 'dev-perl/Mail-IMAPClient',
@@ -417,16 +507,6 @@ my @NeededModules = (
                     ports  => 'security/p5-IO-Socket-SSL',
                 },
             },
-            {
-                Module    => 'Authen::SASL',
-                Required  => 0,
-                Comment   => 'Required for MD5 authentication mechanisms in IMAP connections.',
-                InstTypes => {
-                    aptget => 'libauthen-sasl-perl',
-                    emerge => 'dev-perl/Authen-SASL',
-                    zypper => 'perl-Authen-SASL',
-                },
-            },
             {
                 Module    => 'Authen::NTLM',
                 Required  => 0,
@@ -489,6 +569,17 @@ my @NeededModules = (
             ports  => 'net/p5-perl-ldap',
         },
     },
+    {
+        Module    => 'Net::LDAP::Constant',
+        Required  => 0,
+        Comment   => 'Required for directory authentication.',
+        InstTypes => {
+            aptget => 'libnet-ldap-perl',
+            emerge => 'dev-perl/perl-ldap',
+            zypper => 'perl-ldap',
+            ports  => 'net/p5-perl-ldap',
+        },
+    },
     {
         Module              => 'Net::SMTP',
         Required            => 0,
@@ -506,10 +597,21 @@ my @NeededModules = (
             ports  => undef,
         },
     },
+    {
+        Module    => 'Spreadsheet::XLSX',
+        Required  => 0,
+        Comment   => 'Spreadsheet::XLSX enables import and export of Excel files in certain dialogs.',
+        InstTypes => {
+            aptget => 'libspreadsheet-xlsx-perl',
+            emerge => 'dev-perl/Spreadsheet-XLSX',
+            zypper => 'perl-Spreadsheet-XLSX',
+            ports  => 'www/p5-Spreadsheet-XLSX',
+        },
+    },
     {
         Module    => 'Template',
         Required  => 1,
-        Comment   => 'Template::Toolkit, the rendering engine of OTRS.',
+        Comment   => 'Template::Toolkit, the rendering engine of Znuny.',
         InstTypes => {
             aptget => 'libtemplate-perl',
             emerge => 'dev-perl/Template-Toolkit',
@@ -528,6 +630,17 @@ my @NeededModules = (
             ports  => 'www/p5-Template-Toolkit',
         },
     },
+    {
+        Module    => 'Text::Diff::FormattedHTML',
+        Required  => 1,
+        Comment   => undef,
+        InstTypes => {
+            aptget => undef,
+            emerge => undef,
+            zypper => undef,
+            ports  => undef,
+        },
+    },
     {
         Module    => 'Text::CSV_XS',
         Required  => 0,
@@ -550,6 +663,17 @@ my @NeededModules = (
             ports  => 'devel/p5-Time-HiRes',
         },
     },
+    {
+        Module    => 'Time::Piece',
+        Required  => 1,
+        Comment   => 'Required for calendar events.',
+        InstTypes => {
+            aptget => 'libtime-piece-perl',
+            emerge => 'perl-core/Time-Piece',
+            zypper => 'perl-Time-Piece',
+            ports  => 'devel/p5-Time-Piece',
+        },
+    },
     {
         Module    => 'XML::LibXML',
         Required  => 1,
@@ -867,6 +991,7 @@ sub _VersionClean {
 
     # replace all special characters with an dot
     $Param{Version} =~ s{ [_-] }{.}xmsg;
+    $Param{Version} =~ s{v}{}xmsg;
 
     my @VersionParts = split q{\.}, $Param{Version};
 
